@@ -69,7 +69,7 @@ class PureIter(Generic[_T]):
     def find_first(self, criteria: Callable[[_T], bool]) -> Maybe[_T]:
         result = self._inner.new_iter.map(
             lambda i: _iter_factory.find_first(criteria, i)
-        ).map(Maybe.from_optional)
+        ).map(lambda x: Maybe.from_optional(x))
         return unsafe_unwrap(result)
 
     def chunked(self, size: int) -> PureIter[FrozenList[_T]]:
