@@ -3,7 +3,10 @@ from fa_purity import (
 )
 from fa_purity.cmd import (
     Cmd,
-    unsafe_unwrap,
+)
+from fa_purity.cmd.core import (
+    CmdUnwrapper,
+    new_cmd,
 )
 from fa_purity.maybe import (
     Maybe,
@@ -25,15 +28,15 @@ _T = TypeVar("_T")
 def chain(
     unchained: PureIter[PureIter[_T]],
 ) -> PureIter[_T]:
-    return unsafe_from_cmd(
-        Cmd.from_cmd(lambda: _iter_factory.chain(unchained))
-    )
+    return unchained.bind(lambda x: x)
 
 
 def consume(p_iter: PureIter[Cmd[None]]) -> Cmd[None]:
-    return Cmd.from_cmd(
-        lambda: _iter_factory.deque(unsafe_unwrap(cmd) for cmd in p_iter)
-    )
+    def _action(act: CmdUnwrapper) -> None:
+        for c in p_iter:
+            act.unwrap(c)
+
+    return new_cmd(_action)
 
 
 def filter_opt(items: PureIter[Optional[_T]]) -> PureIter[_T]:
