@@ -20,6 +20,6 @@ def rand_int() -> Cmd[int]:
 
 
 def assert_different_iter(stm: Stream[_T]) -> None:
-    iter1 = unsafe_unwrap(stm._new_iter)
-    iter2 = unsafe_unwrap(stm._new_iter)
+    iter1 = unsafe_unwrap(stm.unsafe_to_iter())
+    iter2 = unsafe_unwrap(stm.unsafe_to_iter())
     assert id(iter1) != id(iter2)
